@@ -14,7 +14,7 @@ use version;
 
 use API::Plesk::Response;
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 
 # creates accessors to components
 # can support old interface of API::Plesk
@@ -23,6 +23,7 @@ init_components(
     customer           => [['1.6.3.0', 'Customer']],
     webspace           => [['1.6.3.0', 'Webspace']],
     site               => [['1.6.3.0', 'Site']],
+    subdomain          => [['1.6.3.0', 'Subdomain']],
     site_alias         => [['1.6.3.0', 'SiteAlias']],
     sitebuilder        => [['1.6.3.0', 'SiteBuilder']],
     ftp_user           => [['1.6.3.0', 'FTPUser']],
@@ -33,8 +34,8 @@ init_components(
     dns                => [['1.6.3.0', 'DNS']],
     mail               => [['1.6.3.0', 'Mail']],
     user               => [['1.6.3.0', 'User']],
-   
-    # old 
+
+    # old
     Accounts => [['1.5.0.0', 'Accounts']],
     Domains  => [['1.5.0.0', 'Domains']],
 );
@@ -43,10 +44,11 @@ init_components(
 sub new {
     my $class = shift;
     $class = ref ($class) || $class;
-    
+
     my $self = {
         username    => '',
         password    => '',
+        secret_key  => '',
         url         => '',
         api_version => '1.6.3.1',
         debug       => 0,
@@ -54,8 +56,10 @@ sub new {
         (@_)
     };
 
-    confess "Required username!" unless $self->{username};
-    confess "Required password!" unless $self->{password};
+    if (!$self->{secret_key}) {
+        confess "Required username!" unless $self->{username};
+        confess "Required password!" unless $self->{password};
+    }
     confess "Required url!"      unless $self->{url};
 
     return bless $self, $class;
@@ -79,7 +83,7 @@ sub send {
 
     unless ( $error ) {
         $response = xml2hash $response, array => [$operation, 'result', 'property'];
-    }    
+    }
 
     return API::Plesk::Response->new(
         operator  => $operator,
@@ -101,15 +105,19 @@ sub xml_http_req {
     my $ua = new LWP::UserAgent( parse_head => 0 );
     my $req = new HTTP::Request POST => $self->{url};
 
-    $req->push_header(':HTTP_AUTH_LOGIN',  $self->{username});
-    $req->push_header(':HTTP_AUTH_PASSWD', $self->{password});
+    if ($self->{secret_key}) {
+        $req->push_header(':KEY',  $self->{secret_key});
+    } else {
+        $req->push_header(':HTTP_AUTH_LOGIN',  $self->{username});
+        $req->push_header(':HTTP_AUTH_PASSWD', $self->{password});
+    }
     $req->content_type('text/xml; charset=UTF-8');
     $req->content($xml);
 
     # LWP6 hack to prevent verification of hostname
     $ua->ssl_opts(verify_hostname => 0) if $ua->can('ssl_opts');
 
-    warn $req->as_string if $self->{debug} > 1;
+    warn $req->as_string   if defined $self->{debug}  &&  $self->{debug} > 1;
 
     my $res = eval {
         local $SIG{ALRM} = sub { die "connection timeout" };
@@ -118,9 +126,9 @@ sub xml_http_req {
     };
     alarm 0;
 
-    warn $res->as_string if $self->{debug} > 1;
+    warn $res->as_string   if defined $self->{debug}  &&  $self->{debug} > 1;
 
-    return ('', 'connection timeout') 
+    return ('', 'connection timeout')
         if !$res || $@ || ref $res && $res->status_line =~ /connection timeout/;
 
     return $res->is_success() ?
@@ -170,7 +178,7 @@ sub _render_xml {
         }
     }
 
-    $xml; 
+    $xml;
 }
 
 
@@ -188,12 +196,12 @@ sub init_components {
             $self->{"_$alias"} ||= $self->load_component($classes);
             return $self->{"_$alias"} || confess "Not implemented!";
         };
-        
+
         no strict 'refs';
- 
+
         *{"$caller\::$alias"} = $sub;
 
-        
+
     }
 
 }
@@ -204,7 +212,7 @@ sub load_component {
     my $version = version->parse($self->{api_version});
 
     for my $item ( @$classes ) {
-        
+
         # select compitable version of component
         if ( $version >= $item->[0] ) {
 
@@ -261,13 +269,13 @@ API::Plesk - OO interface to the Plesk XML API (http://www.parallels.com/en/prod
 
 =head1 DESCRIPTION
 
-At present the module provides interaction with Plesk 10.1 (API 1.6.3.1). 
+At present the module provides interaction with Plesk 10.1 (API 1.6.3.1).
 Distribution was completely rewritten and become more friendly for developers.
 Naming of packages and methods become similar to the same operators and operations of Plesk XML API.
 
 Partially implemented:
 
-API::Plesk::Customer 
+API::Plesk::Customer
 
 API::Plesk::Database
 
@@ -306,9 +314,9 @@ This is develover release. Comapatibility with Plesk::API 1.* is not implemented
 Create new class instance.
 
 Required params:
-username    
-password    
-url         
+username
+password
+url
 
 Additional params:
 api_version - default 1.6.3.1
@@ -336,16 +344,30 @@ Returns array ( $response_xml, $error ).
 =back
 
 =head1 SEE ALSO
- 
+
 Plesk XML RPC API  http://www.parallels.com/en/products/plesk/docs/
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Odintsov Pavel E<lt>nrg[at]cpan.orgE<gt>
 
+Ivan Sokolov E<lt>ivsokolov[at]cpan.orgE<gt>
+
+B<Thanks for contribution:>
+
 Nikolay Shulyakovskiy E<lt>shulyakovskiy[at]rambler.ruE<gt>
 
-Ivan Sokolov E<lt>ivsokolov[at]cpan.orgE<gt>
+bgmilne
+
+Eugeny Zavarykin
+
+Eugen Konkov
+
+Ivan Shamal
+
+Akzhan Abdulin
+
+Jari Turkia
 
 =head1 COPYRIGHT AND LICENSE
 
